@@ -1,5 +1,5 @@
 /**
- * @file sip-sec-ntlm.c
+ * @file sip-sec-ntlm.h
  *
  * pidgin-sipe
  *
@@ -24,8 +24,15 @@
 SipSecContext
 sip_sec_create_context__ntlm(SipSecAuthType type);
 
+void sip_sec_init__ntlm(void);
+void sip_sec_destroy__ntlm(void);
+
 /**
  * Describes NTML messages in human readable form
  */
 gchar *
 sip_sec_ntlm_message_describe(SipSecBuffer buff);
+
+/* temporarily */
+void
+NTOWFv2 (const char* password, const char *user, const char *domain, unsigned char *result);
