@@ -26,8 +26,8 @@
 #include <string.h>
 #include <stdio.h>
 #include "debug.h"
-/* #include "util.h" */
-#include "sip-sec.h"
+#include "sipe.h"
+#include "sipe-utils.h"
 #include "sip-sec-mech.h"
 
 #include "sip-sec-ntlm.h"
@@ -67,19 +67,18 @@ sip_sec_create_context__NONE(SIPE_UNUSED_PARAMETER SipSecAuthType type)
 }
 
 /* sip_sec API methods */
-void
-sip_sec_create_context(SipSecContext *context,
-		       SipSecAuthType type,
+SipSecContext
+sip_sec_create_context(SipSecAuthType type,
 		       const int  sso,
 		       int is_connection_based,
 		       const char *domain,
 		       const char *username,
 		       const char *password)
 {
-	sip_uint32 ret;
+	SipSecContext context = NULL;
 
 	/* Map authentication type to module initialization hook & name */
-	static const sip_sec_create_context_func const auth_to_hook[] = {
+	static sip_sec_create_context_func const auth_to_hook[] = {
 		sip_sec_create_context__NONE,      /* AUTH_TYPE_UNSET     */
 		sip_sec_create_context__NONE,      /* AUTH_TYPE_DIGEST    */
 		sip_sec_create_context__NTLM,      /* AUTH_TYPE_NTLM      */
@@ -87,20 +86,22 @@ sip_sec_create_context(SipSecContext *context,
 		sip_sec_create_context__Negotiate, /* AUTH_TYPE_NEGOTIATE */
 	};
 
-	/* @TODO: Can *context != NULL actually happen? */
-	sip_sec_destroy_context(*context);
+	context = (*(auth_to_hook[type]))(type);
+	if (context) {
+		sip_uint32 ret;
 
-	*context = (*(auth_to_hook[type]))(type);
-	if (!*context) return;
+		context->sso = sso;
+		context->is_connection_based = is_connection_based;
 
-	(*context)->sso = sso;
-	(*context)->is_connection_based = is_connection_based;
-
-	ret = (*(*context)->acquire_cred_func)(*context, domain, username, password);
-	if (ret != SIP_SEC_E_OK) {
-		purple_debug_info("sipe", "ERROR: sip_sec_init_context failed to acquire credentials.\n");
-		return;
+		ret = (*context->acquire_cred_func)(context, domain, username, password);
+		if (ret != SIP_SEC_E_OK) {
+			purple_debug_info("sipe", "ERROR: sip_sec_init_context failed to acquire credentials.\n");
+			(*context->destroy_context_func)(context);
+			context = NULL;
+		}
 	}
+
+	return(context);
 }
 
 unsigned long
@@ -110,43 +111,46 @@ sip_sec_init_context_step(SipSecContext context,
 			  char **output_toked_base64,
 			  int *expires)
 {
-	SipSecBuffer in_buff  = {0, NULL};
-	SipSecBuffer out_buff = {0, NULL};
-	sip_uint32 ret;
-	char *tmp;
+	sip_uint32 ret = SIP_SEC_E_INTERNAL_ERROR;
 
-	/* Not NULL for NTLM Type 2 */
-	if (input_toked_base64) {
-		in_buff.value = purple_base64_decode(input_toked_base64, &(in_buff.length));
+	if (context) {
+		SipSecBuffer in_buff  = {0, NULL};
+		SipSecBuffer out_buff = {0, NULL};
+		char *tmp;
 
-		tmp = sip_sec_ntlm_message_describe(in_buff);
-		if (tmp) {
-			purple_debug_info("sipe", "sip_sec_init_context_step: Chalenge message is:\n%s", tmp);
-		}
-		g_free(tmp);
-	}
+		/* Not NULL for NTLM Type 2 */
+		if (input_toked_base64) {
+			in_buff.value = purple_base64_decode(input_toked_base64, &(in_buff.length));
 
-	ret = (*context->init_context_func)(context, in_buff, &out_buff, target);
-
-	if (input_toked_base64)
-		free_bytes_buffer(&in_buff);
-
-	if (ret == SIP_SEC_E_OK || ret == SIP_SEC_I_CONTINUE_NEEDED) {
-		*output_toked_base64 = purple_base64_encode(out_buff.value, out_buff.length);
-
-		if (out_buff.length > 0 && out_buff.value) {
-			tmp = sip_sec_ntlm_message_describe(out_buff);
+			tmp = sip_sec_ntlm_message_describe(in_buff);
 			if (tmp) {
-				purple_debug_info("sipe", "sip_sec_init_context_step: Negotiate or Authenticate message is:\n%s", tmp);
+				purple_debug_info("sipe", "sip_sec_init_context_step: Challenge message is:\n%s", tmp);
 			}
 			g_free(tmp);
 		}
 
-		free_bytes_buffer(&out_buff);
-	}
+		ret = (*context->init_context_func)(context, in_buff, &out_buff, target);
 
-	if (expires) {
-		*expires = context->expires;
+		if (input_toked_base64)
+			g_free(in_buff.value);
+
+		if (ret == SIP_SEC_E_OK || ret == SIP_SEC_I_CONTINUE_NEEDED) {
+			*output_toked_base64 = purple_base64_encode(out_buff.value, out_buff.length);
+
+			if (out_buff.length > 0 && out_buff.value) {
+				tmp = sip_sec_ntlm_message_describe(out_buff);
+				if (tmp) {
+					purple_debug_info("sipe", "sip_sec_init_context_step: Negotiate or Authenticate message is:\n%s", tmp);
+				}
+				g_free(tmp);
+			}
+
+			g_free(out_buff.value);
+		}
+
+		if (expires) {
+			*expires = context->expires;
+		}
 	}
 
 	return ret;
@@ -167,14 +171,12 @@ sip_sec_init_context(SipSecContext *context,
 	char *output_toked_base64 = NULL;
 	int exp;
 
-	sip_sec_create_context(context,
-			       type,
-			       sso,
-			       0, /* Connectionless for SIP */
-			       domain,
-			       username,
-			       password);
-
+	*context = sip_sec_create_context(type,
+					  sso,
+					  0, /* Connectionless for SIP */
+					  domain,
+					  username,
+					  password);
 	if (!*context) return NULL;
 
 	ret = sip_sec_init_context_step(*context,
@@ -215,8 +217,8 @@ char * sip_sec_make_signature(SipSecContext context, const char *message)
 		purple_debug_info("sipe", "ERROR: sip_sec_make_signature failed. Unable to sign message!\n");
 		return NULL;
 	}
-	signature_hex = bytes_to_hex_str(&signature);
-	free_bytes_buffer(&signature);
+	signature_hex = buff_to_hex_str(signature.value, signature.length);
+	g_free(signature.value);
 	return signature_hex;
 }
 
@@ -230,50 +232,21 @@ int sip_sec_verify_signature(SipSecContext context, const char *message, const c
 
 	if (!message || !signature_hex) return SIP_SEC_E_INTERNAL_ERROR;
 
-	hex_str_to_bytes(signature_hex, &signature);
+	signature.length = hex_str_to_buff(signature_hex, &signature.value);
 	res = (*context->verify_signature_func)(context, message, signature);
-	free_bytes_buffer(&signature);
+	g_free(signature.value);
 	return res;
 }
 
-
-/* Utility Methods */
-
-void hex_str_to_bytes(const char *hex_str, SipSecBuffer *bytes)
+/* Initialize & Destroy */
+void sip_sec_init(void)
 {
-	guint8 *buff;
-	char two_digits[3];
-	size_t i;
-
-	bytes->length = strlen(hex_str)/2;
-	bytes->value = g_malloc(bytes->length);
-
-	buff = (guint8 *)bytes->value;
-	for (i = 0; i < bytes->length; i++) {
-		two_digits[0] = hex_str[i * 2];
-		two_digits[1] = hex_str[i * 2 + 1];
-		two_digits[2] = '\0';
-		buff[i] = (guint8)strtoul(two_digits, NULL, 16);
-	}
+	sip_sec_init__ntlm();
 }
 
-void free_bytes_buffer(SipSecBuffer *bytes)
+void sip_sec_destroy(void)
 {
-	g_free(bytes->value);
-	bytes->length = 0;
-	bytes->value = NULL;
-}
-
-char *bytes_to_hex_str(SipSecBuffer *bytes)
-{
-	guint8 *buff = (guint8 *)bytes->value;
-	char *res    = g_malloc(bytes->length * 2 + 1);
-	size_t i, j;
-	for (i = 0, j = 0; i < bytes->length; i++, j+=2) {
-		sprintf(&res[j], "%02X", buff[i]);
-	}
-	res[j] = '\0';
-	return res;
+	sip_sec_destroy__ntlm();
 }
 
 /*
