@@ -21,18 +21,21 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 #include <glib.h>
 
 #include "debug.h"
 
-#include <sipe.h>
-#include <sipe-cal.h>
-#include <sipe-utils.h>
-#include <sipe-nls.h>
-
-#include <stdlib.h>
+#include "sipe.h"
+#include "sipe-cal.h"
+#include "sipe-utils.h"
+#include "sipe-nls.h"
 
 
 #define TIME_NULL   (time_t)-1
@@ -124,7 +127,7 @@ sipe_cal_get_wday(char *wday_name)
 	if (!wday_name) return -1;
 
 	for (i = 0; i < 7; i++) {
-		if (!strcmp(wday_names[i], wday_name)) {
+		if (sipe_strequal(wday_names[i], wday_name)) {
 			return i;
 		}
 	}
@@ -184,7 +187,7 @@ static void
 sipe_setenv(const char *name,
 	    const char *value)
 {
-#ifndef _WIN32
+#ifdef HAVE_SETENV
 	setenv(name, value, 1);
 #else
 	int len = strlen(name) + 1 + strlen(value) + 1;
@@ -197,7 +200,7 @@ sipe_setenv(const char *name,
 static void
 sipe_unsetenv(const char *name)
 {
-#ifndef _WIN32
+#ifdef HAVE_UNSETENV
 	unsetenv(name);
 #else
 	int len = strlen(name) + 1 + 1;
