@@ -21,6 +21,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 #include <glib.h>
 
@@ -261,7 +265,7 @@ process_invite_conf_focus_response(struct sipe_account_data *sip,
 	} else if (msg->response == 200) {
 		xmlnode *xn_response = xmlnode_from_str(msg->body, msg->bodylen);
 		const gchar *code = xmlnode_get_attrib(xn_response, "code");
-		if (!strcmp(code, "success")) {
+		if (sipe_strequal(code, "success")) {
 			/* subscribe to focus */
 			sipe_subscribe_conference(sip, session, -1);
 		}
@@ -558,7 +562,7 @@ process_conf_add_response(struct sipe_account_data *sip,
 	}
 	if (msg->response == 200) {
 		xmlnode *xn_response = xmlnode_from_str(msg->body, msg->bodylen);
-		if (!strcmp("success", xmlnode_get_attrib(xn_response, "code")))
+		if (sipe_strequal("success", xmlnode_get_attrib(xn_response, "code")))
 		{
 			gchar *who = trans->payload->data;
 			struct sip_session *session;
@@ -651,19 +655,19 @@ process_incoming_invite_conf(struct sipe_account_data *sip,
 	xmlnode *xn_focus_uri = xmlnode_get_child(xn_conferencing, "focus-uri");
 	char *focus_uri = xmlnode_get_data(xn_focus_uri);
 	gchar *newTag = gentag();
-	gchar *oldHeader = sipmsg_find_header(msg, "To");
+	const gchar *oldHeader = sipmsg_find_header(msg, "To");
 	gchar *newHeader;
 
 	xmlnode_free(xn_conferencing);
 
 	/* send OK */
 	purple_debug_info("sipe", "We have received invitation to Conference. Focus URI=%s\n", focus_uri);
-	
+
 	newHeader = g_strdup_printf("%s;tag=%s", oldHeader, newTag);
 	sipmsg_remove_header_now(msg, "To");
 	sipmsg_add_header_now(msg, "To", newHeader);
 	g_free(newHeader);
-	
+
 	/* temporary dialog with invitor */
 	/* take data before 'msg' will be modified by send_sip_response */
 	dialog = g_new0(struct sip_dialog, 1);
@@ -699,7 +703,7 @@ sipe_process_conference(struct sipe_account_data *sip,
 
 	if (msg->response != 0 && msg->response != 200) return;
 
-	if (msg->bodylen == 0 || msg->body == NULL || strcmp(sipmsg_find_header(msg, "Event"), "conference")) return;
+	if (msg->bodylen == 0 || msg->body == NULL || !sipe_strequal(sipmsg_find_header(msg, "Event"), "conference")) return;
 
 	xn_conference_info = xmlnode_from_str(msg->body, msg->bodylen);
 	if (!xn_conference_info) return;
@@ -754,7 +758,7 @@ sipe_process_conference(struct sipe_account_data *sip,
 		{
 			gchar *purpose = xmlnode_get_data(xmlnode_get_child(node, "purpose"));
 
-			if (purpose && !strcmp("chat", purpose)) {
+			if (sipe_strequal("chat", purpose)) {
 				g_free(purpose);
 				session->im_mcu_uri = xmlnode_get_data(xmlnode_get_child(node, "uri"));
 				purple_debug_info("sipe", "sipe_process_conference: im_mcu_uri=%s\n", session->im_mcu_uri);
@@ -775,20 +779,20 @@ sipe_process_conference(struct sipe_account_data *sip,
 		gboolean is_in_im_mcu = FALSE;
 		gchar *self = sip_uri_self(sip);
 
-		if (role && !strcmp(role, "presenter")) {
+		if (sipe_strequal(role, "presenter")) {
 			flags |= PURPLE_CBFLAGS_OP;
 		}
 
-		if (!strcmp("deleted", state)) {
+		if (sipe_strequal("deleted", state)) {
 			if (purple_conv_chat_find_user(chat, user_uri)) {
 				purple_conv_chat_remove_user(chat, user_uri, NULL /* reason */);
 			}
 		} else {
 			/* endpoints */
 			for (endpoint = xmlnode_get_child(node, "endpoint"); endpoint; endpoint = xmlnode_get_next_twin(endpoint)) {
-				if (!strcmp("chat", xmlnode_get_attrib(endpoint, "session-type"))) {
+				if (sipe_strequal("chat", xmlnode_get_attrib(endpoint, "session-type"))) {
 					gchar *status = xmlnode_get_data(xmlnode_get_child(endpoint, "status"));
-					if (!strcmp("connected", status)) {
+					if (sipe_strequal("connected", status)) {
 						is_in_im_mcu = TRUE;
 						if (!purple_conv_chat_find_user(chat, user_uri)) {
 							purple_conv_chat_add_user(chat, user_uri, NULL, flags,
@@ -817,13 +821,13 @@ sipe_process_conference(struct sipe_account_data *sip,
 	     node = xmlnode_get_next_twin(node)) {
 
 		xmlnode *xn_type = xmlnode_get_descendant(node, "entity-state", "media", "entry", "type", NULL);
-		gchar *tmp;
-		if (xn_type && !strcmp("chat", (tmp = xmlnode_get_data(xn_type)))) {
+		gchar *tmp = NULL;
+		if (xn_type && sipe_strequal("chat", (tmp = xmlnode_get_data(xn_type)))) {
 			xmlnode *xn_locked = xmlnode_get_descendant(node, "entity-state", "locked", NULL);
 			if (xn_locked) {
 				gchar *locked = xmlnode_get_data(xn_locked);
 				gboolean prev_locked = session->locked;
-				session->locked = (locked && !strcmp(locked, "true")) ? TRUE : FALSE;
+				session->locked = sipe_strequal(locked, "true");
 				if (prev_locked && !session->locked) {
 					sipe_present_info(sip, session,
 						_("This conference is no longer locked. Additional participants can now join."));
@@ -837,8 +841,8 @@ sipe_process_conference(struct sipe_account_data *sip,
 						          session->locked ? "TRUE" : "FALSE");
 				g_free(locked);
 			}
-			g_free(tmp);
 		}
+		g_free(tmp);
 	}
 	xmlnode_free(xn_conference_info);
 
@@ -851,7 +855,7 @@ sipe_process_conference(struct sipe_account_data *sip,
 			dialog->with = g_strdup(session->im_mcu_uri);
 
 			/* send INVITE to IM MCU */
-			sipe_invite(sip, session, dialog->with, NULL, NULL, FALSE);
+			sipe_invite(sip, session, dialog->with, NULL, NULL, NULL, FALSE);
 		}
 	}
 
@@ -894,7 +898,7 @@ sipe_process_imdn(struct sipe_account_data *sip,
 		  struct sipmsg *msg)
 {
 	gchar *with = parse_from(sipmsg_find_header(msg, "From"));
-	gchar *call_id = sipmsg_find_header(msg, "Call-ID");
+	const gchar *call_id = sipmsg_find_header(msg, "Call-ID");
 	static struct sip_session *session;
 	xmlnode *xn_imdn;
 	xmlnode *node;
@@ -920,7 +924,7 @@ sipe_process_imdn(struct sipe_account_data *sip,
 	for (node = xmlnode_get_child(xn_imdn, "recipient"); node; node = xmlnode_get_next_twin(node)) {
 		gchar *tmp = parse_from(xmlnode_get_attrib(node, "uri"));
 		gchar *uri = parse_from(tmp);
-		sipe_present_message_undelivered_err(sip, session, -1, uri, message);
+		sipe_present_message_undelivered_err(sip, session, -1, -1, uri, message);
 		g_free(tmp);
 		g_free(uri);
 	}
