@@ -196,8 +196,8 @@ sipe_ews_get_oof_note(struct sipe_ews *ews)
 
 	if (!ews || !ews->oof_state) return NULL;
 
-	if (!strcmp(ews->oof_state, "Enabled") ||
-	    (!strcmp(ews->oof_state, "Scheduled") && now >= ews->oof_start && now <= ews->oof_end))
+	if (sipe_strequal(ews->oof_state, "Enabled") ||
+	    (sipe_strequal(ews->oof_state, "Scheduled") && now >= ews->oof_start && now <= ews->oof_end))
 	{
 		return ews->oof_note;
 	}
@@ -213,14 +213,15 @@ sipe_ews_run_state_machine(struct sipe_ews *ews);
 static void
 sipe_ews_process_avail_response(int return_code,
 				const char *body,
+				HttpConn *conn,
 				void *data)
 {
 	struct sipe_ews *ews = data;
 
 	purple_debug_info("sipe", "sipe_ews_process_avail_response: cb started.\n");
 
-	if(ews->oof_url && strcmp(ews->as_url, ews->oof_url)) { /* whether reuse conn */
-		http_conn_set_close(ews->http_conn);
+	if(!sipe_strequal(ews->as_url, ews->oof_url)) { /* whether reuse conn */
+		http_conn_set_close(conn);
 		ews->http_conn = NULL;
 	}
 
@@ -237,7 +238,7 @@ Envelope/Body/GetUserAvailabilityResponse/FreeBusyResponseArray/FreeBusyResponse
 		 */
 		resp = xmlnode_get_descendant(xml, "Body", "GetUserAvailabilityResponse", "FreeBusyResponseArray", "FreeBusyResponse", NULL);
 		if (!resp) return; /* rather soap:Fault */
-		if (strcmp(xmlnode_get_attrib(xmlnode_get_child(resp, "ResponseMessage"), "ResponseClass"), "Success")) {
+		if (!sipe_strequal(xmlnode_get_attrib(xmlnode_get_child(resp, "ResponseMessage"), "ResponseClass"), "Success")) {
 			return; /* Error response */
 		}
 
@@ -289,13 +290,13 @@ Envelope/Body/GetUserAvailabilityResponse/FreeBusyResponseArray/FreeBusyResponse
 			g_free(tmp);
 
 			tmp = xmlnode_get_data(xmlnode_get_child(node, "BusyType"));
-			if (!strcmp("Free", tmp)) {
+			if (sipe_strequal("Free", tmp)) {
 				cal_event->cal_status = SIPE_CAL_FREE;
-			} else if (!strcmp("Tentative", tmp)) {
+			} else if (sipe_strequal("Tentative", tmp)) {
 				cal_event->cal_status = SIPE_CAL_TENTATIVE;
-			} else if (!strcmp("Busy", tmp)) {
+			} else if (sipe_strequal("Busy", tmp)) {
 				cal_event->cal_status = SIPE_CAL_BUSY;
-			} else if (!strcmp("OOF", tmp)) {
+			} else if (sipe_strequal("OOF", tmp)) {
 				cal_event->cal_status = SIPE_CAL_OOF;
 			} else {
 				cal_event->cal_status = SIPE_CAL_NO_DATA;
@@ -306,7 +307,7 @@ Envelope/Body/GetUserAvailabilityResponse/FreeBusyResponseArray/FreeBusyResponse
 			cal_event->location = xmlnode_get_data(xmlnode_get_descendant(node, "CalendarEventDetails", "Location", NULL));
 
 			tmp = xmlnode_get_data(xmlnode_get_descendant(node, "CalendarEventDetails", "IsMeeting", NULL));
-			cal_event->is_meeting = tmp ? !strcmp(tmp, "true") : TRUE;
+			cal_event->is_meeting = tmp ? sipe_strequal(tmp, "true") : TRUE;
 			g_free(tmp);
 		}
 
@@ -323,13 +324,14 @@ Envelope/Body/GetUserAvailabilityResponse/FreeBusyResponseArray/FreeBusyResponse
 static void
 sipe_ews_process_oof_response(int return_code,
 			      const char *body,
+			      HttpConn *conn,
 			      void *data)
 {
 	struct sipe_ews *ews = data;
 
 	purple_debug_info("sipe", "sipe_ews_process_oof_response: cb started.\n");
 
-	http_conn_set_close(ews->http_conn);
+	http_conn_set_close(conn);
 	ews->http_conn = NULL;
 
 	if (return_code == 200 && body) {
@@ -346,7 +348,7 @@ sipe_ews_process_oof_response(int return_code,
 		 */
 		resp = xmlnode_get_descendant(xml, "Body", "GetUserOofSettingsResponse", NULL);
 		if (!resp) return; /* rather soap:Fault */
-		if (strcmp(xmlnode_get_attrib(xmlnode_get_child(resp, "ResponseMessage"), "ResponseClass"), "Success")) {
+		if (!sipe_strequal(xmlnode_get_attrib(xmlnode_get_child(resp, "ResponseMessage"), "ResponseClass"), "Success")) {
 			return; /* Error response */
 		}
 
@@ -355,13 +357,13 @@ sipe_ews_process_oof_response(int return_code,
 
 		old_note = ews->oof_note;
 		ews->oof_note = NULL;
-		if (strcmp(ews->oof_state, "Disabled")) {
+		if (!sipe_strequal(ews->oof_state, "Disabled")) {
 			char *tmp = xmlnode_get_data(
 				xmlnode_get_descendant(resp, "OofSettings", "InternalReply", "Message", NULL));
 			char *html;
 
 			/* UTF-8 encoded BOM (0xEF 0xBB 0xBF) as a signature to mark the beginning of a UTF-8 file */
-			if (tmp && !strncmp(tmp, "\xEF\xBB\xBF", 3)) {
+			if (g_str_has_prefix(tmp, "\xEF\xBB\xBF")) {
 				html = g_strdup(tmp+3);
 			} else {
 				html = g_strdup(tmp);
@@ -373,7 +375,7 @@ sipe_ews_process_oof_response(int return_code,
 			g_free(tmp);
 		}
 
-		if (!strcmp(ews->oof_state, "Scheduled")
+		if (sipe_strequal(ews->oof_state, "Scheduled")
 		    && (xn_duration = xmlnode_get_descendant(resp, "OofSettings", "Duration", NULL)))
 		{
 			char *tmp = xmlnode_get_data(xmlnode_get_child(xn_duration, "StartTime"));
@@ -385,7 +387,7 @@ sipe_ews_process_oof_response(int return_code,
 			g_free(tmp);
 		}
 
-		if (!(old_note && ews->oof_note && !strcmp(old_note, ews->oof_note))) { /* oof note changed */
+		if (!sipe_strequal(old_note, ews->oof_note)) { /* oof note changed */
 			ews->updated = time(NULL);
 			ews->published = FALSE;
 		}
@@ -404,13 +406,14 @@ sipe_ews_process_oof_response(int return_code,
 static void
 sipe_ews_process_autodiscover(int return_code,
 			      const char *body,
+			      HttpConn *conn,
 			      void *data)
 {
 	struct sipe_ews *ews = data;
 
 	purple_debug_info("sipe", "sipe_ews_process_autodiscover: cb started.\n");
 
-	http_conn_set_close(ews->http_conn);
+	http_conn_set_close(conn);
 	ews->http_conn = NULL;
 
 	if (return_code == 200 && body) {
@@ -428,7 +431,7 @@ sipe_ews_process_autodiscover(int return_code,
 		     node = xmlnode_get_next_twin(node))
 		{
 			char *type = xmlnode_get_data(xmlnode_get_child(node, "Type"));
-			if (!strcmp("EXCH", type)) {
+			if (sipe_strequal("EXCH", type)) {
 				ews->as_url  = xmlnode_get_data(xmlnode_get_child(node, "ASUrl"));
 				ews->oof_url = xmlnode_get_data(xmlnode_get_child(node, "OOFUrl"));
 				ews->oab_url = xmlnode_get_data(xmlnode_get_child(node, "OABUrl"));
@@ -483,7 +486,7 @@ sipe_ews_do_autodiscover(struct sipe_ews *ews,
 				 body,
 				 "text/xml",
 				 ews->auth,
-				 (HttpConnCallback)sipe_ews_process_autodiscover,
+				 sipe_ews_process_autodiscover,
 				 ews);
 	g_free(body);
 }
@@ -522,7 +525,7 @@ sipe_ews_do_avail_request(struct sipe_ews *ews)
 					 body,
 					 "text/xml; charset=UTF-8",
 					 ews->auth,
-					 (HttpConnCallback)sipe_ews_process_avail_response,
+					 sipe_ews_process_avail_response,
 					 ews);
 		g_free(body);
 		g_free(start_str);
@@ -547,14 +550,14 @@ sipe_ews_do_oof_request(struct sipe_ews *ews)
 							  body,
 							  content_type,
 							  ews->auth,
-							  (HttpConnCallback)sipe_ews_process_oof_response,
+							  sipe_ews_process_oof_response,
 							  ews);
 		} else {
 			http_conn_post(ews->http_conn,
 				       ews->oof_url,
 				       body,
 				       content_type,
-				       (HttpConnCallback)sipe_ews_process_oof_response,
+				       sipe_ews_process_oof_response,
 				       ews);
 		}
 		g_free(body);
