@@ -115,6 +115,7 @@ struct sip_auth {
 	gchar *opaque;
 	gchar *realm;
 	gchar *target;
+	int version;
 	int nc;
 	int retries;
 	int ntlm_num;
@@ -226,6 +227,7 @@ struct sipe_account_data {
 	GSList *sessions;
 	GSList *openconns;
 	GSList *groups;
+	GHashTable *filetransfers;
 	sipe_transport_type transport;
 	gboolean auto_transport;
 	PurpleSslConnection *gsc;
@@ -372,7 +374,7 @@ send_sip_response(PurpleConnection *gc, struct sipmsg *msg, int code,
 		  const char *text, const char *body);
 void
 sipe_invite(struct sipe_account_data *sip, struct sip_session *session,
-	    const gchar *who, const gchar *msg_body,
+	    const gchar *who, const gchar *msg_body, const gchar *msg_content_type,
 	    const gchar *referred_by, const gboolean is_triggered);
 /* ??? module */
 gboolean process_subscribe_response(struct sipe_account_data *sip,
@@ -388,6 +390,7 @@ void
 sipe_present_message_undelivered_err(struct sipe_account_data *sip,
 				     struct sip_session *session,
 				     int sip_error,
+				     int sip_warning,
 				     const gchar *who,
 				     const gchar *message);
 
@@ -401,9 +404,13 @@ void
 sipe_process_pending_invite_queue(struct sipe_account_data *sip,
 				  struct sip_session *session);
 
+void
+sipe_im_process_queue (struct sipe_account_data * sip, struct sip_session * session);
+
+
 /*** THE BIG SPLIT END ***/
 
-#define SIPE_INVITE_TEXT "ms-text-format: text/plain; charset=UTF-8%s;ms-body=%s\r\n"
+#define SIPE_INVITE_TEXT "ms-text-format: %s; charset=UTF-8%s;ms-body=%s\r\n"
 
 #define SIPE_SEND_TYPING \
 "<?xml version=\"1.0\"?>"\
