@@ -28,6 +28,7 @@
 #include "mime.h"
 
 #include "sipe.h"
+#include "sipe-utils.h"
 #include "sipmsg.h"
 
 struct sipmsg *sipmsg_parse_msg(const gchar *msg) {
@@ -50,11 +51,7 @@ struct sipmsg *sipmsg_parse_header(const gchar *header) {
 	struct sipmsg *msg = g_new0(struct sipmsg,1);
 	gchar **lines = g_strsplit(header,"\r\n",0);
 	gchar **parts;
-	gchar *dummy;
-	gchar *dummy2;
-	gchar *tmp;
-	gchar *contentlength;
-	int i=1;
+	const gchar *contentlength;
 	if(!lines[0]) {
 		g_strfreev(lines);
 		g_free(msg);
@@ -76,29 +73,10 @@ struct sipmsg *sipmsg_parse_header(const gchar *header) {
 		msg->response = 0;
 	}
 	g_strfreev(parts);
-	for(i=1; lines[i] && strlen(lines[i])>2; i++) {
-		parts = g_strsplit(lines[i], ":", 2);
-		if(!parts[0] || !parts[1]) {
-			g_strfreev(parts);
-			g_strfreev(lines);
-			sipmsg_free(msg);
-			return NULL;
-		}
-		dummy = parts[1];
-		dummy2 = 0;
-		while(*dummy==' ' || *dummy=='\t') dummy++;
-		dummy2 = g_strdup(dummy);
-		while(lines[i+1] && (lines[i+1][0]==' ' || lines[i+1][0]=='\t')) {
-			i++;
-			dummy = lines[i];
-			while(*dummy==' ' || *dummy=='\t') dummy++;
-			tmp = g_strdup_printf("%s %s",dummy2, dummy);
-			g_free(dummy2);
-			dummy2 = tmp;
-		}
-		sipmsg_add_header_now(msg, parts[0], dummy2);
-		g_free(dummy2);
-		g_strfreev(parts);
+	if (sipe_utils_parse_lines(&msg->headers,lines + 1) == FALSE) {
+		g_strfreev(lines);
+		sipmsg_free(msg);
+		return NULL;
 	}
 	g_strfreev(lines);
 	contentlength = sipmsg_find_header(msg, "Content-Length");
@@ -108,6 +86,7 @@ struct sipmsg *sipmsg_parse_header(const gchar *header) {
 		purple_debug_fatal("sipe", "sipmsg_parse_header(): Content-Length header not found\n");
 	}
 	if(msg->response) {
+		const gchar *tmp;
 		g_free(msg->method);
 		tmp = sipmsg_find_header(msg, "CSeq");
 		if(!tmp) {
@@ -124,7 +103,7 @@ struct sipmsg *sipmsg_parse_header(const gchar *header) {
 
 void sipmsg_print(const struct sipmsg *msg) {
 	GSList *cur;
-	struct siphdrelement *elem;
+	struct sipnameval *elem;
 	purple_debug(PURPLE_DEBUG_MISC, "sipe", "SIP MSG\n");
 	purple_debug(PURPLE_DEBUG_MISC, "sipe", "response: %d\nmethod: %s\nbodylen: %d\n",msg->response,msg->method,msg->bodylen);
 	if(msg->target) purple_debug(PURPLE_DEBUG_MISC, "sipe", "target: %s\n",msg->target);
@@ -139,7 +118,7 @@ void sipmsg_print(const struct sipmsg *msg) {
 char *sipmsg_to_string(const struct sipmsg *msg) {
 	GSList *cur;
 	GString *outstr = g_string_new("");
-	struct siphdrelement *elem;
+	struct sipnameval *elem;
 
 	if(msg->response)
 		g_string_append_printf(outstr, "SIP/2.0 %d Unknown\r\n",
@@ -152,7 +131,7 @@ char *sipmsg_to_string(const struct sipmsg *msg) {
 	while(cur) {
 		elem = cur->data;
                 /*Todo: remove the LFCR in a good way*/
-                /*if(!strcmp(elem->name,"Proxy-Authorization"))
+                /*if(sipe_strequal(elem->name,"Proxy-Authorization"))
                   g_string_append_printf(outstr, "%s: %s", elem->name,
 			elem->value);
                 else     */
@@ -170,7 +149,7 @@ char *sipmsg_to_string(const struct sipmsg *msg) {
  * Adds header to current message headers at specified position
  */
 void sipmsg_add_header_now_pos(struct sipmsg *msg, const gchar *name, const gchar *value, int pos) {
-	struct siphdrelement *element = g_new0(struct siphdrelement,1);
+	struct sipnameval *element = g_new0(struct sipnameval,1);
 
 	/* SANITY CHECK: the calling code must be fixed if this happens! */
 	if (!value) {
@@ -188,7 +167,7 @@ void sipmsg_add_header_now_pos(struct sipmsg *msg, const gchar *name, const gcha
  * Adds header to current message headers
  */
 void sipmsg_add_header_now(struct sipmsg *msg, const gchar *name, const gchar *value) {
-	struct siphdrelement *element = g_new0(struct siphdrelement,1);
+	struct sipnameval *element = g_new0(struct sipnameval,1);
 
 	/* SANITY CHECK: the calling code must be fixed if this happens! */
 	if (!value) {
@@ -206,7 +185,7 @@ void sipmsg_add_header_now(struct sipmsg *msg, const gchar *name, const gchar *v
  * Adds header to separate storage for future merge
  */
 void sipmsg_add_header(struct sipmsg *msg, const gchar *name, const gchar *value) {
-	struct siphdrelement *element = g_new0(struct siphdrelement,1);
+	struct sipnameval *element = g_new0(struct sipnameval,1);
 
 	/* SANITY CHECK: the calling code must be fixed if this happens! */
 	if (!value) {
@@ -225,7 +204,7 @@ void sipmsg_add_header(struct sipmsg *msg, const gchar *name, const gchar *value
  */
 void sipmsg_strip_headers(struct sipmsg *msg, const gchar *keepers[]) {
 	GSList *entry;
-	struct siphdrelement *elem;
+	struct sipnameval *elem;
 
 	entry = msg->headers;
 	while(entry) {
@@ -266,21 +245,8 @@ void sipmsg_merge_new_headers(struct sipmsg *msg) {
 }
 
 void sipmsg_free(struct sipmsg *msg) {
-	struct siphdrelement *elem;
-	while(msg->headers) {
-		elem = msg->headers->data;
-		msg->headers = g_slist_remove(msg->headers,elem);
-		g_free(elem->name);
-		g_free(elem->value);
-		g_free(elem);
-	}
-	while(msg->new_headers) {
-		elem = msg->new_headers->data;
-		msg->new_headers = g_slist_remove(msg->new_headers,elem);
-		g_free(elem->name);
-		g_free(elem->value);
-		g_free(elem);
-	}
+	sipe_utils_nameval_free(msg->headers);
+	sipe_utils_nameval_free(msg->new_headers);
 	g_free(msg->signature);
 	g_free(msg->rand);
 	g_free(msg->num);
@@ -291,7 +257,7 @@ void sipmsg_free(struct sipmsg *msg) {
 }
 
 void sipmsg_remove_header_now(struct sipmsg *msg, const gchar *name) {
-	struct siphdrelement *elem;
+	struct sipnameval *elem;
 	GSList *tmp = msg->headers;
 	while(tmp) {
 		elem = tmp->data;
@@ -308,27 +274,12 @@ void sipmsg_remove_header_now(struct sipmsg *msg, const gchar *name) {
 	return;
 }
 
-gchar *sipmsg_find_header(const struct sipmsg *msg, const gchar *name) {
-	return sipmsg_find_header_instance (msg, name, 0);
+const gchar *sipmsg_find_header(const struct sipmsg *msg, const gchar *name) {
+	return sipe_utils_nameval_find_instance (msg->headers, name, 0);
 }
 
-gchar *sipmsg_find_header_instance(const struct sipmsg *msg, const gchar *name, int which) {
-	GSList *tmp;
-	struct siphdrelement *elem;
-	int i = 0;
-	tmp = msg->headers;
-	while(tmp) {
-		elem = tmp->data;
-		// OCS2005 can send the same header in either all caps or mixed case
-		if (g_ascii_strcasecmp(elem->name,name)==0) {
-			if (i == which) {
-				return elem->value;
-			}
-			i++;
-		}
-		tmp = g_slist_next(tmp);
-	}
-	return NULL;
+const gchar *sipmsg_find_header_instance(const struct sipmsg *msg, const gchar *name, int which) {
+	return sipe_utils_nameval_find_instance(msg->headers, name, which);
 }
 
 gchar *sipmsg_find_part_of_header(const char *hdr, const char * before, const char * after, const char * def) {
@@ -408,7 +359,7 @@ GSList *sipmsg_parse_endpoints_header(const gchar *header)
 
 gchar *sipmsg_find_auth_header(struct sipmsg *msg, const gchar *name) {
 	GSList *tmp;
-	struct siphdrelement *elem;
+	struct sipnameval *elem;
 	int name_len = strlen(name);
 	tmp = msg->headers;
 	while(tmp) {
@@ -504,14 +455,13 @@ gchar *sipmsg_apply_x_mms_im_format(const char *x_mms_im_format, gchar *body) {
 /* ms-text-format: text/plain; charset=UTF-8;msgr=WAAtAE0...DIADQAKAA0ACgA;ms-body=SGk= */
 gchar *get_html_message(const gchar *ms_text_format_in, const gchar *body_in)
 {
-	gchar *tmp_html;
 	gchar *msgr;
 	gchar *res;
 	gchar *ms_text_format = NULL;
 	gchar *body = NULL;
 
-	if (!strncmp(ms_text_format_in, "multipart/related", 17) ||
-	    !strncmp(ms_text_format_in, "multipart/alternative", 21)) {
+	if (g_str_has_prefix(ms_text_format_in, "multipart/related") ||
+	    g_str_has_prefix(ms_text_format_in, "multipart/alternative")) {
 		char *doc = g_strdup_printf("Content-Type: %s\r\n\r\n%s", ms_text_format_in, body_in);
 		PurpleMimeDocument *mime;
 		GList* parts;
@@ -525,11 +475,11 @@ gchar *get_html_message(const gchar *ms_text_format_in, const gchar *body_in)
 				guint length = purple_mime_part_get_length(parts->data);
 
 				/* if no other format has stored */
-				if (!ms_text_format && !strncmp(content_type, "text/plain", 10)) {
+				if (!ms_text_format && g_str_has_prefix(content_type, "text/plain")) {
 					ms_text_format = g_strdup(content_type);
 					body = g_strndup(content, length);
 				/* preferred format */
-				} else if (ms_text_format && !strncmp(ms_text_format, "text/html", 9)) {
+				} else if (g_str_has_prefix(ms_text_format, "text/html")) {
 					g_free(ms_text_format);
 					g_free(body);
 					ms_text_format = g_strdup(content_type);
@@ -548,37 +498,38 @@ gchar *get_html_message(const gchar *ms_text_format_in, const gchar *body_in)
 	}
 
 	if (body) {
-		res = g_strdup(body);
+		res = body;
 	} else {
-		res = sipmsg_find_part_of_header(ms_text_format, "ms-body=", NULL, NULL);
-		if (!res) return NULL;
-		tmp_html = res;
-		res = (gchar *) purple_base64_decode(res, NULL);
-		g_free(tmp_html);
+		gchar *tmp = sipmsg_find_part_of_header(ms_text_format, "ms-body=", NULL, NULL);
+		if (!tmp) {
+			g_free(ms_text_format);
+			return NULL;
+		}
+		res = (gchar *) purple_base64_decode(tmp, NULL);
+		g_free(tmp);
+		if (!res) {
+			g_free(ms_text_format);
+			return NULL;
+		}
 	}
 
-	if (!res) {
-		return NULL;
-	}
-
-	if (ms_text_format && strncmp(ms_text_format, "text/html", 9)) { // NOT html
-		tmp_html = res;
+	if (!g_str_has_prefix(ms_text_format, "text/html")) { // NOT html
+		char *tmp = res;
 		res = g_markup_escape_text(res, -1); // as this is not html
-		g_free(tmp_html);
+		g_free(tmp);
 	}
 
 	msgr = sipmsg_find_part_of_header(ms_text_format, "msgr=", ";", NULL);
 	if (msgr) {
 		gchar *x_mms_im_format = sipmsg_get_x_mms_im_format(msgr);
+		gchar *tmp = res;
 		g_free(msgr);
-		tmp_html = res;
 		res = sipmsg_apply_x_mms_im_format(x_mms_im_format, res);
-		g_free(tmp_html);
+		g_free(tmp);
 		g_free(x_mms_im_format);
 	}
 
 	g_free(ms_text_format);
-	g_free(body);
 
 	return res;
 }
@@ -846,20 +797,20 @@ msn_import_html(const char *html, char **attributes, char **message)
 					else if (!g_ascii_strncasecmp(c, "style=\"", 7))
 					{
 						/* Parse inline CSS attributes */
-						char *attributes;
 						int attr_len = 0;
 						c += 7;
 						while (*(c + attr_len) != '\0' && *(c + attr_len) != '"')
 							attr_len++;
 						if (*(c + attr_len) == '"')
 						{
+							char *css_attributes;
 							char *attr_dir;
-							attributes = g_strndup(c, attr_len);
-							attr_dir = purple_markup_get_css_property(attributes, "direction");
+							css_attributes = g_strndup(c, attr_len);
+							attr_dir = purple_markup_get_css_property(css_attributes, "direction");
+							g_free(css_attributes);
 							if (attr_dir && (!g_ascii_strncasecmp(attr_dir, "RTL", 3)))
 								direction = '1';
 							g_free(attr_dir);
-							g_free(attributes);
 						}
 
 					}
@@ -906,6 +857,7 @@ msn_import_html(const char *html, char **attributes, char **message)
 					else
 						namelen = (unsigned int)(comma - c);
 
+					g_free(fontface);
 					fontface = g_strndup(c, namelen);
 					c = end + 2;
 				}
